@@ -2,9 +2,9 @@ package Test::Pretty;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
-use Test::Builder;
+use Test::Builder 0.82;
 use Term::Encoding ();
 use File::Spec ();
 use Term::ANSIColor qw/colored/;
